# Generated by Django 4.2.11 on 2025-01-15 10:00

from django.db import migrations, models, connection


def move_ptr_id(apps, schema_editor):
    AbstractBasePage = apps.get_model("ocyan_plugin_wagtail", "AbstractBasePage")

    for migrated_model in ["coyotehomepage", "coyotecontactpage"]:
        Model = apps.get_model("coyote", migrated_model)

        Model.objects.all().update(abstractbasepage_ptr=models.F("page_ptr"))

        with connection.cursor() as cursor:
            for p in Model.objects.all():
                cursor.execute(
                    "INSERT INTO ocyan_plugin_wagtail_abstractbasepage (page_ptr_id, search_image_id) VALUES (%s, %s)"
                    % (p.page_ptr_id, p.search_image_id or "Null")
                )


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0022_add_abstractbasepage_fields"),
    ]

    operations = [migrations.RunPython(move_ptr_id, migrations.RunPython.noop)]



from django import forms
from django.db.models import Model
from django.utils.functional import cached_property

from wagtail import blocks
from wagtail.admin.telepath import register

from ocyan.plugin.coyote.definitions import get_coyote_definitions
from ocyan.plugin.coyote.utils import LinkPageString, LocalizedLinkPage

from .adapters import (
    AdminLinkChooserAdapter,
    ColorChoiceAdapter,
    IconChoiceAdapter,
    VisualChoiceAdapter,
)
from .fields import LinkModelChoiceField
from .widgets import AdminLinkChooser, ColorSelect, IconSelect, VisualSelect


class ColorChoiceBlock(blocks.ChoiceBlock):
    def __init__(self, *args, **kwargs):
        kwargs["required"] = False
        super().__init__(*args, **kwargs)

    def choices(self):
        definitions = get_coyote_definitions()
        return [
            ("background_body", definitions["body-background"]),
            ("dark", definitions["gray-900"]),
            ("light", definitions["gray-200"]),
        ]

    def get_field(self, **kwargs):
        kwargs["widget"] = ColorSelect
        return forms.ChoiceField(**kwargs)

    class Meta:
        admin_text = ""
        label = " "


class VisualChoiceBlock(blocks.ChoiceBlock):
    def get_field(self, **kwargs):
        kwargs["widget"] = VisualSelect
        return forms.ChoiceField(**kwargs)


class IconChoiceBlock(blocks.ChoiceBlock):
    def get_field(self, **kwargs):
        kwargs["widget"] = IconSelect
        return forms.ChoiceField(**kwargs)


class LinkChooserBlock(blocks.PageChooserBlock):
    @cached_property
    def field(self):
        return LinkModelChoiceField(
            queryset=self.target_model.objects.all(),
            widget=self.widget,
            required=self._required,
            validators=self._validators,
            help_text=self._help_text,
        )

    @cached_property
    def widget(self):
        return AdminLinkChooser(
            target_models=self.target_models, can_choose_root=self.can_choose_root
        )

    def value_from_form(self, value):
        if isinstance(value, str):
            return value

        return super().value_from_form(value)

    def get_prep_value(self, value):
        if isinstance(value, LocalizedLinkPage):
            return value.pk

        if isinstance(value, self.target_model):
            return value.pk

        return value

    def to_python(self, value):
        value = super().to_python(value)
        if isinstance(value, self.target_model):
            return LocalizedLinkPage(value)
        if isinstance(value, str):
            return LinkPageString(value)
        return value

    def bulk_to_python(self, values):
        ids = filter(lambda x: isinstance(x, int), values)
        objects = self.target_model.objects.in_bulk(ids)

        def to_usable_value(_value):
            value = objects.get(_value, _value)

            if isinstance(value, str):
                return LinkPageString(value)
            if isinstance(value, self.target_model):
                return LocalizedLinkPage(value)

            return value

        return list(map(to_usable_value, values))

    def extract_references(self, value):
        if isinstance(value, LocalizedLinkPage):
            value = value.page

        if (
            value is not None
            and issubclass(self.model_class, Model)
            and isinstance(value, Model)
        ):
            yield self.model_class, str(value.pk), "", ""


register(ColorChoiceAdapter(), ColorSelect)
register(VisualChoiceAdapter(), VisualSelect)
register(IconChoiceAdapter(), IconSelect)
register(AdminLinkChooserAdapter(), AdminLinkChooser)



# Generated by Django 4.2.20 on 2025-05-30 07:38
from django.db import migrations
from django.conf import settings
from oxyan.themes.definitions import theme


def forward(apps, schema_editor):
    StyleSettings = apps.get_model('coyote', 'StyleSettings')

    valid_options = getattr(settings, 'OXYAN_HEADER_OPTIONS', [])
    valid_option_values = [option[0] for option in valid_options] if valid_options else []

    theme_default = theme.get("header", "basic")
    if theme_default not in valid_option_values and valid_option_values:
        theme_default = "basic"

    for style_setting in StyleSettings.objects.all():
        if style_setting.header and style_setting.header not in valid_option_values:
            style_setting.header = theme_default
            style_setting.save()


class Migration(migrations.Migration):
    dependencies = [
        ('coyote', '0020_stylesettings_header'),
    ]

    operations = [
        migrations.RunPython(forward, migrations.RunPython.noop)
    ]



from django.utils.translation import gettext as _

from wagtail import blocks
from wagtail.embeds.blocks import EmbedBlock
from wagtail.images.blocks import ImageChooserBlock

from ocyan.plugin.coyote.custom_blocks import VisualChoiceBlock
from ocyan.plugin.coyote.struct_values import CoyoteEmbedBlockValue

from .partials import CoyoteButtonBlock, CoyoteInlineBlock


class CoyoteImages(blocks.StructBlock):
    image = ImageChooserBlock(label=_("Image"))
    body = blocks.RichTextBlock(
        label=_("Body"),
        required=True,
        features=["h1", "h2", "h3", "h4", "bold", "italic", "link"],
    )
    image = ImageChooserBlock(label=_("Image"))
    ornaments = CoyoteInlineBlock(
        [
            ("overlay", blocks.BooleanBlock(required=False, label=_("Dark overlay"))),
            (
                "center_text",
                blocks.BooleanBlock(required=False, label=_("Center the body")),
            ),
            ("wave", blocks.BooleanBlock(required=False, label=_("Wave underline"))),
        ],
        label=_("Ornaments"),
    )
    buttons = blocks.ListBlock(
        CoyoteButtonBlock(), label=_("Buttons"), required=False, collapsed=True
    )

    class Meta:
        label = _("Pictures")
        icon = "image"
        template = "coyote/blocks/header/images.html"


class CoyoteVideo(blocks.StructBlock):
    layout = VisualChoiceBlock(
        choices=[
            ("layout1", "coyote/layouts/video_layout_1.png"),
            ("layout2", "coyote/layouts/video_layout_2.png"),
        ],
        default="layout1",
        label=_("Layout"),
    )
    video = EmbedBlock(label=_("Video"), required=False)
    overlay = blocks.BooleanBlock(required=False, label=_("Dark overlay"))
    body = blocks.RichTextBlock(
        label=_("Body"),
        required=True,
        features=["h1", "h2", "h3", "h4", "bold", "italic", "link"],
    )
    buttons = blocks.ListBlock(
        CoyoteButtonBlock(), label=_("Buttons"), required=False, collapsed=True
    )

    class Meta:
        label = _("Video")
        icon = "media"
        template = "coyote/blocks/header/video.html"
        value_class = CoyoteEmbedBlockValue


class CoyoteContent(blocks.StructBlock):
    image = ImageChooserBlock(label=_("Image"))
    position = blocks.ChoiceBlock(
        label=_("Position of the image"),
        choices=[
            ("left", _("Left")),
            ("right", _("Right")),
        ],
        required=False,
    )
    body = blocks.RichTextBlock(
        label=_("Body"),
        required=True,
        features=["h1", "h2", "h3", "h4", "bold", "italic", "link"],
    )
    buttons = blocks.ListBlock(
        CoyoteButtonBlock(), label=_("Buttons"), required=False, collapsed=True
    )

    class Meta:
        label = _("Text")
        icon = "italic"
        template = "coyote/blocks/header/content.html"


class CoyoteCHeaderImages(blocks.StructBlock):
    image = ImageChooserBlock(label=_("Image"))
    overlay = blocks.BooleanBlock(required=False, label=_("Dark overlay"))
    body = blocks.RichTextBlock(
        label=_("Body"),
        required=True,
        features=["h1", "h2", "h3", "h4", "bold", "italic", "link"],
    )
    centered = blocks.BooleanBlock(required=False, label=_("Centered"))
    buttons = blocks.ListBlock(
        CoyoteButtonBlock(), label=_("Buttons"), required=False, collapsed=True
    )
    title = blocks.CharBlock(required=True, label=_("Title"))

    class Meta:
        icon = "image"
        template = "coyote/blocks/header/c_images.html"



# Generated by Django 3.2.23 on 2023-11-13 15:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('coyote', '0007_auto_20231113_1608'),
    ]

    operations = [
        migrations.RenameField(
            model_name='colorsetting',
            old_name='body_bg',
            new_name='body_background',
        ),
    ]



import uuid

from django.utils.translation import gettext as _

from wagtail import blocks
from wagtail.images.blocks import ImageChooserBlock

from ocyan.plugin.coyote.custom_blocks import (
    IconChoiceBlock,
    LinkChooserBlock,
    VisualChoiceBlock,
)
from ocyan.plugin.coyote.icons import ICONS

from .partials import CoyoteButtonBlock, CoyoteStructBlock


class BootstrapTabBlock(blocks.StructBlock):
    header = blocks.CharBlock(label=_("Title"))
    body = blocks.RichTextBlock(label=_("Body"))
    button = CoyoteButtonBlock(required=False, label=_("Button"))


class CoyoteTabsBlock(CoyoteStructBlock):
    header = blocks.CharBlock(label=_("Title"), required=False)
    image = ImageChooserBlock(label=_("Image"))
    tabs = blocks.ListBlock(
        BootstrapTabBlock(), label=_("Tabbed content"), required=False, collapsed=True
    )

    def get_uuid(self):
        return uuid.uuid4()

    class Meta:
        icon = "table"
        template = "coyote/blocks/content/tabsblock.html"


class CoyoteIconBlock(blocks.StructBlock):
    icon = IconChoiceBlock(choices=ICONS, required=False, label=_("Icon"))
    image = ImageChooserBlock(required=False, label=_("Image"))
    header = blocks.CharBlock(required=False, label=_("Title"))
    body = blocks.TextBlock(label=_("Body"), required=False, max_length=150)
    link = LinkChooserBlock(label=_("Link"), required=False)

    class Meta:
        icon = "tick-inverse"


class CoyoteIconsWithText(CoyoteStructBlock):
    layout = VisualChoiceBlock(
        choices=[
            ("layout1", "coyote/layouts/icon_layout_1.png"),
            ("layout2", "coyote/layouts/icon_layout_2.png"),
            ("layout3", "coyote/layouts/icon_layout_3.png"),
        ],
        default="layout1",
        label=_("Layout"),
    )
    body = blocks.RichTextBlock(label=_("Body"), required=False)
    icons = blocks.ListBlock(
        CoyoteIconBlock(), label=_("Icons"), required=False, collapsed=True
    )
    button = CoyoteButtonBlock(required=False, label=_("Button"))

    class Meta:
        icon = "info-circle"
        template = "coyote/blocks/content/icons_with_text.html"


class CoyoteLogos(CoyoteStructBlock):
    header = blocks.CharBlock(label=_("Title"), required=False)
    logos = blocks.ListBlock(
        ImageChooserBlock(), required=False, collapsed=True, label=_("Logos")
    )

    class Meta:
        icon = "image"
        template = "coyote/blocks/content/logo_slider.html"
        label = "Logo slider"


class CoyoteCenterText(CoyoteStructBlock):
    body = blocks.RichTextBlock(required=False, label=_("Body"))
    image = ImageChooserBlock(required=False, label=_("Image"))
    buttons = blocks.ListBlock(
        CoyoteButtonBlock(required=False), required=False, label=_("Buttons")
    )

    class Meta:
        template = "coyote/blocks/content/centertext.html"


class CounterAttribute(blocks.StructBlock):
    number = blocks.CharBlock(required=False, label=_("Number"), max_length=20)
    label = blocks.CharBlock(required=False, label=_("Label"), max_length=50)

    class Meta:
        icon = "repeat"


class CoyoteImageWithText(CoyoteStructBlock):
    layout = VisualChoiceBlock(
        choices=[
            ("layout1", "coyote/layouts/layout_image_text_2.png"),
            ("layout2", "coyote/layouts/layout_image_text_1.png"),
        ],
        default="layout1",
        label=_("Layout"),
    )
    image = ImageChooserBlock(label=_("Image"))
    image_fill = blocks.BooleanBlock(
        required=False, label=_("Scale image to content size"), default=True
    )
    body = blocks.RichTextBlock(required=False, label=_("Body"))
    buttons = blocks.ListBlock(
        CoyoteButtonBlock(), label=_("Buttons"), required=False, collapsed=True
    )
    counter = blocks.ListBlock(
        CounterAttribute(), label=_("Counter"), required=False, collapsed=True
    )

    class Meta:
        template = "coyote/blocks/content/image_with_text.html"


class CoyoteAccordionBlock(blocks.StructBlock):
    header = blocks.CharBlock(required=False, label=_("Title"))
    body = blocks.RichTextBlock(required=False, label=_("Body"))
    button = CoyoteButtonBlock(required=False, label=_("Button"))

    class Meta:
        icon = "arrow-down"


class CoyoteAccordionAllBlock(CoyoteStructBlock):
    header = blocks.CharBlock(required=False, label=_("Title"))
    body = blocks.RichTextBlock(required=False, label=_("Body"))
    accordion = blocks.ListBlock(
        CoyoteAccordionBlock(), required=True, collapsed=True, label=_("Accordion")
    )

    class Meta:
        template = "coyote/blocks/content/accordion.html"


class CoyotePersonBlock(blocks.StructBlock):
    image = ImageChooserBlock(required=True, label=_("Image"))
    name = blocks.CharBlock(required=True, label=_("Full name"))
    function = blocks.CharBlock(required=False, label=_("Function"))
    instagram = blocks.CharBlock(required=False, label=_("Instagram"))
    facebook = blocks.CharBlock(required=False, label=_("Facebook"))
    linkedin = blocks.CharBlock(required=False, label=_("LinkedIn"))
    twitter = blocks.CharBlock(required=False, label=_("Twitter"))

    class Meta:
        icon = "user"


class CoyotePersonListBlock(CoyoteStructBlock):
    body = blocks.RichTextBlock(required=False, label=_("Body"))
    persons = blocks.ListBlock(CoyotePersonBlock(), required=True, collapsed=True)

    class Meta:
        template = "coyote/blocks/content/personsblock.html"


class CoyoteQuoteBlock(blocks.StructBlock):
    image = ImageChooserBlock(required=False, label=_("Image"))
    name = blocks.CharBlock(required=False, label=_("Full name"))
    function = blocks.CharBlock(required=False, label=_("Function"))
    quote = blocks.TextBlock(required=False, label=_("Quote"))


class CoyoteQuotesBlock(CoyoteStructBlock):
    body = blocks.RichTextBlock(required=False, label=_("Introduction"))
    quotes = blocks.ListBlock(
        CoyoteQuoteBlock(), required=True, collapsed=True, label=_("Quotes")
    )

    class Meta:
        template = "coyote/blocks/content/quotesblock.html"
        icon = "openquote"


class CoyoteTextListBlock(CoyoteStructBlock):
    layout = VisualChoiceBlock(
        choices=[
            ("layout1", "coyote/layouts/textlist_layout_1.png"),
            ("layout2", "coyote/layouts/textlist_layout_2.png"),
            ("layout3", "coyote/layouts/textlist_layout_3.png"),
        ],
        default="layout1",
        label=_("Layout"),
    )
    body = blocks.RichTextBlock(required=False, label=_("Body"))
    buttons = blocks.ListBlock(
        CoyoteButtonBlock(required=False),
        required=False,
        collapsed=True,
        label=_("Buttons"),
    )
    body_list = blocks.ListBlock(
        blocks.RichTextBlock(), required=True, collapsed=True, label=_("Paragraphs")
    )

    class Meta:
        template = "coyote/blocks/content/textlistblock.html"



# Generated by Django 4.2.11 on 2024-03-27 14:54

from django.db import migrations
import ocyan.plugin.coyote.fields


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0012_auto_20240308_0914"),
    ]

    operations = [
        migrations.AlterField(
            model_name="coyotecontactpage",
            name="content",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Inhoud"
            ),
        ),
        migrations.AlterField(
            model_name="coyotecontactpage",
            name="footer",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Footer"
            ),
        ),
        migrations.AlterField(
            model_name="coyotecontactpage",
            name="header",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Header"
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="content",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Inhoud"
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="footer",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Footer"
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="header",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Header"
            ),
        ),
    ]



from django import forms
from django.utils.functional import cached_property

from wagtail.admin.telepath.widgets import WidgetAdapter
from wagtail.admin.staticfiles import versioned_static
from wagtail.admin.widgets.chooser import PageChooserAdapter


class CoyoteAdapterMediaMixin:
    @cached_property
    def media(self):
        return super().media + forms.Media(
            js=[
                versioned_static("wagtailadmin/js/telepath/blocks.js"),
                versioned_static("wagtailadmin/js/page-chooser-modal.js"),
                versioned_static("wagtailadmin/js/page-chooser-telepath.js"),
                versioned_static("wagtailadmin/coyote/coyote.js"),
            ],
            css={
                "all": [
                    versioned_static("css/external.css"),
                    versioned_static("wagtailadmin/coyote/coyote.css"),
                ]
            },
        )


class VisualChoiceAdapter(CoyoteAdapterMediaMixin, WidgetAdapter):
    js_constructor = "coyote.widgets.VisualChoice"


class ColorChoiceAdapter(CoyoteAdapterMediaMixin, WidgetAdapter):
    js_constructor = "coyote.widgets.ColorChoice"


class IconChoiceAdapter(CoyoteAdapterMediaMixin, WidgetAdapter):
    js_constructor = "coyote.widgets.IconChoice"


class AdminLinkChooserAdapter(CoyoteAdapterMediaMixin, PageChooserAdapter):
    js_constructor = "coyote.widgets.AdminLinkChooser"



# Generated by Django 4.2.11 on 2025-04-30 12:08

from django.db import migrations, models
from oxyan.themes.definitions import theme


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0016_alter_stylesettings_header_font_variant_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="stylesettings",
            name="body_color",
            field=models.CharField(default=theme["body-color"], max_length=7),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="border_radius",
            field=models.DecimalField(decimal_places=2, default=theme["border-radius"], max_digits=6),
        ),
    ]



from django.conf import settings
from django.db import models
from django.utils.functional import cached_property
from django.utils.translation import gettext_lazy as _

# pylint: disable=E0401,E0611
from oxyan.themes.definitions import theme

from wagtail.admin.panels import (
    FieldPanel,
    FieldRowPanel,
    MultiFieldPanel,
)
from wagtail.contrib.settings.models import BaseSiteSetting, register_setting
from wagtail.search import index

from ocyan.core.fender import config
from ocyan.main.loading import get_ocyan_class, get_ocyan_classes

from .fields import CoyoteStreamField
from .forms import StyleSettingsForm

# pylint: disable=unbalanced-tuple-unpacking
(
    HomePageHeaderStreamBlock,
    HomePageContentStreamBlock,
    HomePageFooterStreamBlock,
    ContactPageHeaderStreamBlock,
    ContactPageContentStreamBlock,
    ContactPageFooterStreamBlock,
) = get_ocyan_classes(
    "coyote.stream_blocks",
    (
        "HomePageHeaderStreamBlock",
        "HomePageContentStreamBlock",
        "HomePageFooterStreamBlock",
        "ContactPageHeaderStreamBlock",
        "ContactPageContentStreamBlock",
        "ContactPageFooterStreamBlock",
    ),
)

AbstractBasePage = get_ocyan_class("ocyan_plugin_wagtail.models", "AbstractBasePage")


@register_setting
class StyleSettings(BaseSiteSetting):
    primary = models.CharField(max_length=7, default=theme["primary"])
    secondary = models.CharField(max_length=7, default=theme["secondary"])
    gray_900 = models.CharField(max_length=7, default=theme["gray-900"])
    gray_200 = models.CharField(max_length=7, default=theme["gray-200"])
    body_color = models.CharField(max_length=7, default=theme["body-color"])
    body_background = models.CharField(max_length=7, default=theme["body-background"])
    footer_background = models.CharField(
        max_length=7, default=theme["footer-background"]
    )
    header_background = models.CharField(
        max_length=7, default=theme["header-background"]
    )

    header_font = models.CharField(max_length=255, blank=True, null=True)
    paragraph_font = models.CharField(max_length=255, blank=True, null=True)
    header_font_family = models.CharField(max_length=255, blank=True, null=True)
    paragraph_font_family = models.CharField(max_length=255, blank=True, null=True)
    header_font_variant = models.CharField(max_length=255, default="")
    paragraph_font_variant = models.CharField(max_length=255, default="")

    border_radius = models.DecimalField(
        max_digits=6, decimal_places=2, default=theme["border-radius"]
    )

    header = models.CharField(
        max_length=255,
        null=True,
        choices=settings.OXYAN_HEADER_OPTIONS,
        default=theme.get("header", "basic"),
    )

    panels = [
        MultiFieldPanel(
            (
                FieldRowPanel(
                    (
                        FieldPanel("primary"),
                        FieldPanel("secondary"),
                    )
                ),
                FieldRowPanel(
                    (
                        FieldPanel("body_color"),
                        FieldPanel("gray_900"),
                        FieldPanel("gray_200"),
                    )
                ),
                FieldRowPanel(
                    (
                        FieldPanel("body_background"),
                        FieldPanel("footer_background"),
                        FieldPanel("header_background"),
                    )
                ),
            ),
            heading=_("Colors"),
            classname="collapsed",
        ),
        MultiFieldPanel(
            (
                FieldRowPanel(
                    (
                        FieldPanel("header_font_family"),
                        FieldPanel("header_font_variant"),
                        FieldPanel("paragraph_font_family"),
                        FieldPanel("paragraph_font_variant"),
                    ),
                    classname="fontpanel",
                ),
                FieldRowPanel(
                    (
                        FieldPanel("header_font"),
                        FieldPanel("paragraph_font"),
                    )
                ),
            ),
            heading=_("Typography"),
            classname="collapsed",
        ),
        MultiFieldPanel(
            (
                FieldPanel("border_radius"),
                # Do not display the header options if they are not available
                *([FieldPanel("header")] if settings.OXYAN_HEADER_OPTIONS else []),
            ),
            heading=_("General"),
            classname="collapsed",
        ),
    ]

    @cached_property
    def definitions(self):
        basket_counter_background = config.get(
            "themes", "basket-counter-background", self.primary
        )
        header_font_family = (
            [f'"{self.header_font_family}"', "sans-serif"]
            if self.header_font_family
            else None
        )
        paragraph_font_family = (
            [f'"{self.paragraph_font_family}"', "sans-serif"]
            if self.paragraph_font_family
            else None
        )

        return {
            # colors
            "primary": self.primary,
            "secondary": self.secondary,
            "gray-900": self.gray_900,
            "gray-200": self.gray_200,
            "body-color": self.body_color,
            "body-background": self.body_background,
            "footer-background": self.footer_background,
            "header-background": self.header_background,
            "basket-counter-background": basket_counter_background,
            # font
            "header-font-family": header_font_family,
            "font-family-sans-serif": paragraph_font_family,
            "font-weight-headers": (
                "700" if "bold" in self.header_font_variant else "400"
            ),
            "font-weight-normal": (
                "700" if "bold" in self.paragraph_font_variant else "400"
            ),
            "headings-font-style": (
                "italic" if "italic" in self.header_font_variant else "normal"
            ),
            "border-radius": self.border_radius,
            "header": self.header,
        }

    class Meta:
        verbose_name = "Template page settings"

    base_form_class = StyleSettingsForm


class CoyoteHomePage(AbstractBasePage):
    template = "coyote/pages/home.html"

    header = CoyoteStreamField(
        HomePageHeaderStreamBlock(),
        blank=True,
        verbose_name="Header",
        max_num=1,
        use_json_field=True,
    )
    content = CoyoteStreamField(
        HomePageContentStreamBlock(),
        blank=True,
        verbose_name=_("Content"),
        collapsed=True,
        use_json_field=True,
    )
    footer = CoyoteStreamField(
        HomePageFooterStreamBlock(),
        blank=True,
        verbose_name="Footer",
        max_num=1,
        use_json_field=True,
    )

    content_panels = AbstractBasePage.content_panels + [
        FieldPanel("header", classname="collapsible"),
        FieldPanel("content", classname="collapsible"),
        FieldPanel("footer", classname="collapsible"),
    ]

    search_fields = AbstractBasePage.search_fields + [
        index.SearchField("header", partial_match=True),
        index.SearchField("content", partial_match=True),
        index.SearchField("footer", partial_match=True),
    ]

    page_description = _(
        "Predefined layout that ensures your content always looks good."
    )

    class Meta:
        verbose_name = "Template page"


class CoyoteContactPage(AbstractBasePage):
    is_creatable = "ocyan.plugin.contact_form" in config.ocyan_plugins
    template = "coyote/pages/contact.html"

    header = CoyoteStreamField(
        ContactPageHeaderStreamBlock(),
        blank=True,
        verbose_name="Header",
        max_num=1,
        use_json_field=True,
    )
    content = CoyoteStreamField(
        ContactPageContentStreamBlock(),
        blank=True,
        verbose_name=_("Content"),
        use_json_field=True,
    )
    footer = CoyoteStreamField(
        ContactPageFooterStreamBlock(),
        blank=True,
        verbose_name="Footer",
        max_num=1,
        use_json_field=True,
    )

    content_panels = AbstractBasePage.content_panels + [
        FieldPanel("header", classname="collapsible"),
        FieldPanel("content", classname="collapsible"),
        FieldPanel("footer", classname="collapsible"),
    ]

    search_fields = AbstractBasePage.search_fields + [
        index.SearchField("header", partial_match=True),
        index.SearchField("content", partial_match=True),
        index.SearchField("footer", partial_match=True),
    ]

    page_description = _(
        "Predefined layout that ensures your contact page always looks good."
    )

    class Meta:
        verbose_name = "Contact template page"



from django.db import migrations, models
from oxyan.themes.definitions import theme


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0013_alter_coyotecontactpage_content_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="stylesettings",
            name="site",
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="body_background",
            field=models.CharField(default=theme["body-background"], max_length=7),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="footer_background",
            field=models.CharField(default=theme["footer-background"], max_length=7),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="gray_200",
            field=models.CharField(default=theme["gray-200"], max_length=7),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="gray_900",
            field=models.CharField(default=theme["gray-900"], max_length=7),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="header_background",
            field=models.CharField(default=theme["header-background"], max_length=7),
        ),
    ]



# Generated by Django 4.2.11 on 2025-05-20 07:25

from django.db import migrations, models
from django.conf import settings
from oxyan.themes.definitions import theme


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0019_auto_20250512_1642"),
    ]

    operations = [
        migrations.AddField(
            model_name="stylesettings",
            name="header",
            field=models.CharField(max_length=255, null=True, default=theme.get("header", "basic"), choices=settings.OXYAN_HEADER_OPTIONS),
        ),
    ]



# Generated by Django 4.2.11 on 2025-02-18 15:42

from django.db import migrations, models, utils
import django.db.models.deletion


def get_default_site_id():
    from wagtail.models import Site
    try:
        return Site.objects.get(is_default_site=True).id
    except Site.DoesNotExist:
        return Site.objects.first().id


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0094_alter_page_locale"),
        ("coyote", "0014_remove_stylesettings_site_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="stylesettings",
            name="header_font",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="header_font_family",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="header_font_variant",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="paragraph_font",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="paragraph_font_family",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="paragraph_font_variant",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="site",
            field=models.OneToOneField(
                default=get_default_site_id,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                to="wagtailcore.site",
            ),
            preserve_default=False,
        ),
    ]



# Generated by Django 4.2.11 on 2025-05-01 09:47

from django.db import migrations, models
from oxyan.themes.definitions import theme

class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0017_stylesettings_body_color_stylesettings_border_radius"),
    ]

    operations = [
        migrations.AlterField(
            model_name="stylesettings",
            name="border_radius",
            field=models.DecimalField(decimal_places=2, default=theme["border-radius"], max_digits=6),
        ),
    ]



from importlib import import_module
from pathlib import Path

from configtype.jsonconfig import setup_search_paths

BASE_DIR = Path(__file__).resolve().parents[5]
setup_search_paths("/etc/ocyan/", str(BASE_DIR))


def _patch_ocyan_test_bootstrap():
    # Keep the isolated Coyote test settings out of the broader Ocyan
    # block-plugin discovery chain. The smoke suite validates Coyote itself and
    # should not pull in optional settings blocks from unrelated plugins such
    # as newsletter.
    wagtail_block_plugin = import_module("ocyan.plugin.wagtail.block_plugin")
    wagtail_block_plugin.get_extra_ocyan_settings_blocks = lambda: []

    # The generic Ocyan class loader normally walks the full project extension
    # graph. For plugin-local smoke tests we only want the directly installed
    # base module for each request, not unrelated host overrides such as
    # webshop extensions.
    ocyan_loading = import_module("ocyan.main.loading")
    ocyan_loading.ocyan_class_loader.get_extension_module_names = (
        lambda oscar_app_name, installed_apps_entry: [installed_apps_entry]
    )


_patch_ocyan_test_bootstrap()

SECRET_KEY = "coyote-test-key"
DEBUG = True
USE_TZ = True
TIME_ZONE = "UTC"
ALLOWED_HOSTS = ["*"]
ROOT_URLCONF = "ocyan.plugin.coyote.test_urls"
STATIC_URL = "/static/"
STATIC_ROOT = str(BASE_DIR / "static")
COMPRESS_ROOT = STATIC_ROOT
SITE_ID = 1
DEFAULT_AUTO_FIELD = "django.db.models.AutoField"
WAGTAILADMIN_BASE_URL = "http://testserver"

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": ":memory:",
    }
}

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.messages",
    "django.contrib.sessions",
    "django.contrib.sites",
    "django.contrib.staticfiles",
    "compressor",
    "modelcluster",
    "taggit",
    "wagtail",
    "wagtail.admin",
    "wagtail.documents",
    "wagtail.embeds",
    "wagtail.images",
    "wagtail.search",
    "wagtail.sites",
    "wagtail.snippets",
    "wagtail.users",
    "wagtail.contrib.forms",
    "wagtail.contrib.redirects",
    "wagtail.contrib.settings",
    "wagtailmetadata",
    "roadrunner",
    "ocyan.main",
    "oxyan.themes",
    "ocyan.plugin.wagtail_i18n",
    "ocyan.plugin.wagtail",
    "ocyan.plugin.coyote",
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
]

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    }
]

PASSWORD_HASHERS = [
    "django.contrib.auth.hashers.MD5PasswordHasher",
]

OXYAN_THEME = "default"
OXYAN_THEME_MIXINS = []
OXYAN_HEADER_OPTIONS = []
OXYAN_LAZY_THEME_DEFINITIONS = "ocyan.plugin.coyote.definitions.get_coyote_definitions"

COMPRESS_ENABLED = False



from uuid import uuid4

from django import template
from django.template import TemplateDoesNotExist
from django.template.loader import render_to_string
from django.urls import NoReverseMatch, reverse

register = template.Library()


@register.simple_tag
def get_unique_id():
    return uuid4().hex


@register.simple_tag
def optional_url(view_name, *args, **kwargs):
    try:
        return reverse(view_name, args=args, kwargs=kwargs)
    except NoReverseMatch:
        return ""


@register.simple_tag(takes_context=True)
def render_optional_template(context, template_name, **kwargs):
    try:
        rendered_context = (
            context.flatten() if hasattr(context, "flatten") else dict(context)
        )
        rendered_context.update(kwargs)
        return render_to_string(template_name, rendered_context)
    except TemplateDoesNotExist:
        return ""



from django.conf import settings
from django.core.cache import caches
from django.db.models.signals import post_save
from django.dispatch import receiver

from .models import StyleSettings


@receiver(post_save, sender=StyleSettings)
def clear_compress_backend(*_, **__):
    caches[settings.COMPRESS_CACHE_BACKEND].clear()



from django import forms
from django.utils.translation import gettext_lazy as _

from wagtail.admin.forms import WagtailAdminModelForm

from .utils import get_google_fonts


class ColorPickerWidget(forms.TextInput):
    template_name = "coyote/forms/widgets/colorpicker.html"


class FontSelectWidget(forms.TextInput):
    template_name = "coyote/forms/widgets/fontselect.html"

    def get_context(self, name, value, attrs):
        context = super().get_context(name, value, attrs)
        context["fonts"] = get_google_fonts()
        return context


class FontPreviewWidget(forms.TextInput):
    template_name = "coyote/forms/widgets/fontpreview.html"


class StyleSettingsForm(WagtailAdminModelForm):
    primary = forms.CharField(widget=ColorPickerWidget(), label=_("Primary color"))
    secondary = forms.CharField(widget=ColorPickerWidget(), label=_("Secondary color"))
    gray_900 = forms.CharField(widget=ColorPickerWidget(), label=_("Dark accent color"))
    gray_200 = forms.CharField(
        widget=ColorPickerWidget(), label=_("Light accent color")
    )
    body_color = forms.CharField(widget=ColorPickerWidget(), label=_("Body text color"))
    body_background = forms.CharField(
        widget=ColorPickerWidget(), label=_("Body background color")
    )
    footer_background = forms.CharField(
        widget=ColorPickerWidget(), label=_("Footer background color")
    )
    header_background = forms.CharField(
        widget=ColorPickerWidget(), label=_("Header background color")
    )

    header_font_variant = forms.CharField(
        label=_("Variant"),
        widget=forms.Select(
            choices=map(lambda x: (x, x), ["normal", "bold", "italic", "bold italic"])
        ),
    )
    paragraph_font_variant = forms.CharField(
        label=_("Variant"),
        widget=forms.Select(choices=map(lambda x: (x, x), ["normal", "bold"])),
    )

    header_font_family = forms.CharField(
        required=False,
        widget=FontSelectWidget(),
        label=_("Heading font family"),
        help_text=_("Used for headings across the Coyote theme."),
    )
    paragraph_font_family = forms.CharField(
        required=False,
        widget=FontSelectWidget(),
        label=_("Body font family"),
        help_text=_("Used for paragraph text across the Coyote theme."),
    )

    header_font = forms.CharField(
        required=False,
        widget=FontPreviewWidget(
            attrs=dict(preview="""
                    <h1>Lorem ipsum dolor</h1>
                    <h2>Lorem ipsum dolor</h2>
                    <h3>Lorem ipsum dolor</h3>
                    <h4>Lorem ipsum dolor</h4>
                    <h5>Lorem ipsum dolor</h5>
                    <h6>Lorem ipsum dolor</h6>
                """),
        ),
        label=_("Heading font"),
    )
    paragraph_font = forms.CharField(
        required=False,
        widget=FontPreviewWidget(
            attrs=dict(preview="""
                    <p>
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus lacinia odio vitae vestibulum vestibulum. 
                        Cras venenatis euismod malesuada. Donec eget lorem non urna volutpat tincidunt at non eros.
                        <br><br>
                        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus lacinia odio vitae vestibulum vestibulum. 
                        Cras venenatis euismod malesuada. Donec eget lorem non urna volutpat tincidunt at non eros.
                    </p>
                """),
        ),
        label=_("Body font"),
    )

    border_radius = forms.DecimalField(
        label=_("Border radius"),
        help_text=_("Applies the shared border radius used by Coyote components."),
    )

    class Media:
        js = (
            "wagtailadmin/coyote/stylesettingscolorpicker.js",
            "external/js/jquery.js",
            "external/js/select2.js",
            "fontadmin/js/font.js",
        )
        css = {
            "all": [
                "wagtailadmin/coyote/stylesettingscolorpicker.css",
                "external/css/select2.css",
                "external/css/select2-bs5-theme.css",
                "fontadmin/css/font.css",
            ],
        }



from .utils import exclude_none_values


def get_style_settings():
    from wagtail.models import Site

    from ocyan.plugin.wagtail.middleware import get_current_request

    from ocyan.plugin.coyote.models import StyleSettings

    request = get_current_request()

    if request is not None:
        if not hasattr(request, "style_settings"):
            request.style_settings = StyleSettings.for_request(request)

        return request.style_settings

    else:
        return StyleSettings.for_site(Site.objects.get(is_default_site=True))


def get_coyote_definitions():
    style = get_style_settings()
    return exclude_none_values(style.definitions)



from importlib import import_module

from django.apps import AppConfig


class OcyanPluginCoyoteAppConfig(AppConfig):
    name = "ocyan.plugin.coyote"
    label = "coyote"

    def ready(self):
        import_module(f"{self.name}.signals")



from urllib.parse import urlparse, urlunparse

from bs4 import BeautifulSoup

from wagtail import blocks


class CoyoteEmbedBlockValue(blocks.StructValue):
    def auto_play(self):
        video_soup = BeautifulSoup(str(self.get("video")), "html.parser")

        parsed_url = urlparse(video_soup.iframe["src"])
        embed_id = parsed_url.path.split("/")[-1]
        parsed_url = parsed_url._replace(
            query="rel=0&autoplay=1&loop=1&showinfo=0&mute=1&playlist=" + embed_id
        )

        video_soup.iframe["src"] = urlunparse(parsed_url)
        video_soup.iframe["autoplay"] = "1"
        video_soup.iframe["frameborder"] = "0"

        return video_soup



# Generated by Django 4.2.11 on 2025-02-19 16:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0015_stylesettings_header_font_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="stylesettings",
            name="header_font_variant",
            field=models.CharField(default="", max_length=255),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="paragraph_font_variant",
            field=models.CharField(default="", max_length=255),
        ),
    ]



from django import template
from django.template.loader import render_to_string

from ..definitions import get_style_settings

register = template.Library()


@register.simple_tag()
def load_fonts():
    font_settings = get_style_settings()
    return render_to_string(
        "coyote/partials/fonts.html", {"font_settings": font_settings}
    )



from django.utils.translation import gettext_lazy as _

from wagtail import blocks

from ocyan.plugin.coyote.custom_blocks import IconChoiceBlock
from ocyan.plugin.coyote.icons import ICONS

from .partials import CoyoteButtonBlock


class CoyoteCallToAction(blocks.StructBlock):
    icon = IconChoiceBlock(choices=ICONS, required=False, label=_("Icon"))
    header = blocks.CharBlock(required=False, label=_("Title"))
    body = blocks.TextBlock(required=False, label=_("Body"))
    button = CoyoteButtonBlock(required=False, label=_("Button"))

    class Meta:
        template = "coyote/blocks/footer/calltoaction.html"
        icon = "comment-add"
